library xappbase;

import 'package:flutter/material.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:xappbase/screens/SettingsPage/settings_service.dart';

import 'screens/SettingsPage/SettingsPage.Controller.dart';
import 'screens/SampleForUI/sample_item_details_view.dart';
import 'screens/SampleForUI/sample_item_list_view.dart';
import 'screens/SettingsPage/Settings.BL.dart';

/// Classe Base dell'app da configurare.
class XAppBase extends StatelessWidget {
  const XAppBase({
    Key? key,
    this.settingsController,
    this.changeNotifier,
    this.initialRoute,
  }) : super(key: key);

  final SettingsController? settingsController;
  final dynamic changeNotifier;
  final String? initialRoute;

  // ///Chiamalo dall'esterno per overridarlo
  // static void main() async {
  //   final settingsController = SettingsController(SettingsService());
  //   await settingsController.loadSettings();
  //   runApp(XAppBase(
  //     settingsController: settingsController,
  //   ));
  // }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: settingsController!,
      builder: (BuildContext context, Widget? child) {
        return MaterialApp(
          restorationScopeId: 'app',
          localizationsDelegates: const [
            GlobalMaterialLocalizations.delegate,
          ],
          supportedLocales: const [
            Locale('en', ''),
            Locale('it', ''),
          ],
          initialRoute: initialRoute,
          theme: ThemeData(),
          darkTheme: ThemeData.dark(),
          themeMode: settingsController!.themeMode,
          onGenerateRoute: (RouteSettings routeSettings) {
            return MaterialPageRoute<void>(
              settings: routeSettings,
              builder: (BuildContext context) {
                switch (routeSettings.name) {
                  case SettingsPage.routeName:
                    return SettingsPage(
                      controller: settingsController,
                      title: "Settings",
                      changeNotifierClass: changeNotifier,
                    );
                  case SampleItemDetailsView.routeName:
                    return const SampleItemDetailsView();
                  case SampleItemListView.routeName:
                  default:
                    return SampleItemListView();
                }
              },
            );
          },
          debugShowCheckedModeBanner: false,
        );
      },
    );
  }
}
